==> com.liferay.dynamic.data.mapping.form.renderer-5.0.27.jar: META-INF/resources/js/components/Field/MetalComponentAdapter.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@5.0.27/js/components/Field/MetalComponentAdapter.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../../actions/eventTypes.es', '../../hooks/useForm.es', '../../hooks/usePage.es', './MetalFieldAdapter.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.MetalComponentAdapter = void 0;

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _eventTypes = require("../../actions/eventTypes.es");

  var _useForm = require("../../hooks/useForm.es");

  var _usePage2 = require("../../hooks/usePage.es");

  var _MetalFieldAdapter = _interopRequireDefault(require("./MetalFieldAdapter.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _extends() {
    _extends = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }return target;
    };return _extends.apply(this, arguments);
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};var target = _objectWithoutPropertiesLoose(source, excluded);var key, i;if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];if (excluded.indexOf(key) >= 0) continue;if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;target[key] = source[key];
      }
    }return target;
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};var target = {};var sourceKeys = Object.keys(source);var key, i;for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];if (excluded.indexOf(key) >= 0) continue;target[key] = source[key];
    }return target;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var NoRender =
  /*#__PURE__*/
  function (_React$Component) {
    _inherits(NoRender, _React$Component);

    function NoRender() {
      _classCallCheck(this, NoRender);

      return _possibleConstructorReturn(this, _getPrototypeOf(NoRender).apply(this, arguments));
    }

    _createClass(NoRender, [{
      key: "shouldComponentUpdate",
      value: function shouldComponentUpdate() {
        return false;
      }
    }, {
      key: "render",
      value: function render() {
        var _this$props = this.props,
            forwardRef = _this$props.forwardRef,
            otherProps = _objectWithoutProperties(_this$props, ["forwardRef"]);

        return _react["default"].createElement("div", _extends({
          ref: forwardRef
        }, otherProps));
      }
    }]);

    return NoRender;
  }(_react["default"].Component);

  var MetalComponentAdapter = function MetalComponentAdapter(_ref) {
    var onBlur = _ref.onBlur,
        onChange = _ref.onChange,
        onFocus = _ref.onFocus,
        type = _ref.type,
        field = _objectWithoutProperties(_ref, ["onBlur", "onChange", "onFocus", "type"]);

    var _usePage = (0, _usePage2.usePage)(),
        activePage = _usePage.activePage,
        editable = _usePage.editable,
        pageIndex = _usePage.pageIndex,
        spritemap = _usePage.spritemap;

    var dispatch = (0, _useForm.useForm)();
    var component = (0, _react.useRef)(null);
    var container = (0, _react.useRef)(null);
    (0, _react.useEffect)(function () {
      if (!component.current && container.current) {
        component.current = new _MetalFieldAdapter["default"]({
          activePage: activePage,
          editable: editable,
          field: field,
          onBlur: onBlur,
          onChange: onChange,
          onFocus: onFocus,
          onRemoved: function onRemoved(_, event) {
            return dispatch({
              payload: event,
              type: _eventTypes.EVENT_TYPES.REMOVED
            });
          },
          onRepeated: function onRepeated(_, event) {
            return dispatch({
              payload: event,
              type: _eventTypes.EVENT_TYPES.REPEATED
            });
          },
          pageIndex: pageIndex,
          spritemap: spritemap,
          type: type
        }, container.current);
      }

      return function () {
        if (component.current) {
          component.current.dispose();
        }
      }; // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    (0, _react.useEffect)(function () {
      if (component.current) {
        component.current.setState({
          activePage: activePage,
          editable: editable,
          field: field,
          pageIndex: pageIndex,
          spritemap: spritemap
        });
      }
    }, [activePage, editable, pageIndex, spritemap, field]);
    return _react["default"].createElement(NoRender, {
      forwardRef: container
    });
  };

  exports.MetalComponentAdapter = MetalComponentAdapter;
  //# sourceMappingURL=MetalComponentAdapter.es.js.map
});
//# sourceMappingURL=MetalComponentAdapter.es.js.map

==> com.liferay.dynamic.data.mapping.form.renderer-5.0.33.jar: META-INF/resources/js/components/Field/MetalComponentAdapter.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@5.0.33/js/components/Field/MetalComponentAdapter.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../../actions/eventTypes.es', '../../hooks/useForm.es', '../../hooks/usePage.es', './MetalFieldAdapter.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.MetalComponentAdapter = void 0;

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _eventTypes = require("../../actions/eventTypes.es");

  var _useForm = require("../../hooks/useForm.es");

  var _usePage2 = require("../../hooks/usePage.es");

  var _MetalFieldAdapter = _interopRequireDefault(require("./MetalFieldAdapter.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _extends() {
    _extends = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }return target;
    };return _extends.apply(this, arguments);
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};var target = _objectWithoutPropertiesLoose(source, excluded);var key, i;if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];if (excluded.indexOf(key) >= 0) continue;if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;target[key] = source[key];
      }
    }return target;
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};var target = {};var sourceKeys = Object.keys(source);var key, i;for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];if (excluded.indexOf(key) >= 0) continue;target[key] = source[key];
    }return target;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var NoRender = /*#__PURE__*/function (_React$Component) {
    _inherits(NoRender, _React$Component);

    function NoRender() {
      _classCallCheck(this, NoRender);

      return _possibleConstructorReturn(this, _getPrototypeOf(NoRender).apply(this, arguments));
    }

    _createClass(NoRender, [{
      key: "shouldComponentUpdate",
      value: function shouldComponentUpdate() {
        return false;
      }
    }, {
      key: "render",
      value: function render() {
        var _this$props = this.props,
            forwardRef = _this$props.forwardRef,
            otherProps = _objectWithoutProperties(_this$props, ["forwardRef"]);

        return _react["default"].createElement("div", _extends({
          ref: forwardRef
        }, otherProps));
      }
    }]);

    return NoRender;
  }(_react["default"].Component);

  var MetalComponentAdapter = function MetalComponentAdapter(_ref) {
    var onBlur = _ref.onBlur,
        onChange = _ref.onChange,
        onFocus = _ref.onFocus,
        type = _ref.type,
        field = _objectWithoutProperties(_ref, ["onBlur", "onChange", "onFocus", "type"]);

    var _usePage = (0, _usePage2.usePage)(),
        activePage = _usePage.activePage,
        editable = _usePage.editable,
        pageIndex = _usePage.pageIndex,
        spritemap = _usePage.spritemap;

    var dispatch = (0, _useForm.useForm)();
    var component = (0, _react.useRef)(null);
    var container = (0, _react.useRef)(null);
    (0, _react.useEffect)(function () {
      if (!component.current && container.current) {
        component.current = new _MetalFieldAdapter["default"]({
          activePage: activePage,
          editable: editable,
          field: field,
          onBlur: onBlur,
          onChange: onChange,
          onFocus: onFocus,
          onRemoved: function onRemoved(_, event) {
            return dispatch({
              payload: event,
              type: _eventTypes.EVENT_TYPES.FIELD_REMOVED
            });
          },
          onRepeated: function onRepeated(_, event) {
            return dispatch({
              payload: event,
              type: _eventTypes.EVENT_TYPES.FIELD_REPEATED
            });
          },
          pageIndex: pageIndex,
          spritemap: spritemap,
          type: type
        }, container.current);
      }

      return function () {
        if (component.current) {
          component.current.dispose();
        }
      }; // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    (0, _react.useEffect)(function () {
      if (component.current) {
        component.current.setState({
          activePage: activePage,
          editable: editable,
          field: field,
          pageIndex: pageIndex,
          spritemap: spritemap
        });
      }
    }, [activePage, editable, pageIndex, spritemap, field]);
    return _react["default"].createElement(NoRender, {
      forwardRef: container
    });
  };

  exports.MetalComponentAdapter = MetalComponentAdapter;
  //# sourceMappingURL=MetalComponentAdapter.es.js.map
});
//# sourceMappingURL=MetalComponentAdapter.es.js.map
